[master] 093b112 Fix synth handling and update docs

Federico G. Schwindt fgsch at lodoss.net
Thu Aug 6 10:28:17 CEST 2015


commit 093b11238e6f4e9624b8386893930eacf4060536
Author: Federico G. Schwindt <fgsch at lodoss.net>
Date:   Thu Aug 6 09:17:01 2015 +0100

    Fix synth handling and update docs
    
    error has been long retired.

diff --git a/doc/sphinx/reference/varnishncsa.rst b/doc/sphinx/reference/varnishncsa.rst
index 3ab7759..d98f6e2 100644
--- a/doc/sphinx/reference/varnishncsa.rst
+++ b/doc/sphinx/reference/varnishncsa.rst
@@ -119,7 +119,7 @@ Supported formatters are:
 
   Varnish:handling
     How the request was handled, whether it was a cache hit, miss,
-    pass, pipe or error.
+    pass, pipe or synth.
 
   VCL_Log:key
     Output value set by std.log("key:value") in VCL.



More information about the varnish-commit mailing list
diff --git a/bin/varnishncsa/varnishncsa.c b/bin/varnishncsa/varnishncsa.c
index 257a39d..9283beb 100644
--- a/bin/varnishncsa/varnishncsa.c
+++ b/bin/varnishncsa/varnishncsa.c
@@ -879,12 +879,12 @@ dispatch_f(struct VSL_data *vsl, struct VSL_transaction * const pt[],
 				} else if (!strcasecmp(b, "pass")) {
 					CTX.hitmiss = "miss";
 					CTX.handling = "pass";
-				} else if (!strcasecmp(b, "error")) {
-					/* Arguably, error isn't a hit or
+				} else if (!strcasecmp(b, "synth")) {
+					/* Arguably, synth isn't a hit or
 					   a miss, but miss is less
 					   wrong */
 					CTX.hitmiss = "miss";
-					CTX.handling = "error";
+					CTX.handling = "synth";
 				}
 				break;
 			case SLT_VCL_return: